@@ -1,10 +1,11 @@
 
 package String::Tokenizer;
 
+use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use constant RETAIN_WHITESPACE => 1;
 use constant IGNORE_WHITESPACE => 0;
@@ -44,19 +45,19 @@ sub tokenize {
     # if we are asking about whitespace then handle it
     $self->handleWhitespace($handle_whitespace) if defined $handle_whitespace;
     # if the two above are not handled, then the object will use
-    # the values set already. 
+    # the values set already.
 	# split everything by whitespace no matter what
-	# (possible multiple occurances of white space too) 
+	# (possible multiple occurances of white space too)
 	my @tokens;
     if ($self->{handle_whitespace}) {
         @tokens = split /(\s+)/ => $string;
     }
     else {
-        @tokens = split /\s+/ => $string;    
+        @tokens = split /\s+/ => $string;
     }
 	if ($self->{delimiter}) {
 		# create the delimiter reg-ex
-		# escape all non-alpha-numeric 
+		# escape all non-alpha-numeric
 		# characters, just to be safe
 		my $delimiter = $self->{delimiter};
 		# loop through the tokens
@@ -71,7 +72,7 @@ sub tokenize {
 						if ($char =~ /^$delimiter$/) {
 							# and we already have a token in the works
 							if (defined($token) && $token =~ /^.*$/) {
-								# add the token to the 
+								# add the token to the
 								# temp tokens list
 								push @_tokens => $token;
 							}
@@ -89,13 +90,13 @@ sub tokenize {
 							$token .= $char;
 						}
 					}
-					# now push any remaining token onto 
+					# now push any remaining token onto
 					# the temp tokens list
 					push @_tokens => $token if defined $token;
 					# and return tokens
 					@_tokens;
 				}
-				# if our token does not have 
+				# if our token does not have
 				# the delimiter in it
 				else {
 					# just return it
@@ -126,7 +127,7 @@ use strict;
 use warnings;
 
 sub new {
-    ((caller())[0] eq "String::Tokenizer") 
+    ((caller())[0] eq "String::Tokenizer")
         || die "Insufficient Access Priviledges : Only String::Tokenizer can create String::Tokenizer::Iterator instances";
     my ($_class, $tokens) = @_;
     my $class = ref($_class) || $_class;
@@ -145,36 +146,36 @@ sub reset {
 
 sub hasNextToken {
     my ($self) = @_;
-    return ($self->{index} < scalar @{$self->{tokens}}) ? 1 : 0;    
+    return ($self->{index} < scalar @{$self->{tokens}}) ? 1 : 0;
 }
 
 sub hasPrevToken {
     my ($self) = @_;
-    return ($self->{index} > 0);  
+    return ($self->{index} > 0);
 }
 
 sub nextToken {
     my ($self) = @_;
-    return undef if ($self->{index} >= scalar @{$self->{tokens}});    
+    return undef if ($self->{index} >= scalar @{$self->{tokens}});
     return $self->{tokens}->[$self->{index}++];
 }
 
 sub prevToken {
     my ($self) = @_;
-    return undef if ($self->{index} <= 0);    
+    return undef if ($self->{index} <= 0);
     return $self->{tokens}->[--$self->{index}];
 }
 
 sub currentToken {
     my ($self) = @_;
-    return $self->{tokens}->[$self->{index} - 1];      
+    return $self->{tokens}->[$self->{index} - 1];
 }
 
 sub lookAheadToken {
     my ($self) = @_;
-    return undef if (  $self->{index} <= 0 
+    return undef if (  $self->{index} <= 0
                     || $self->{index} >= scalar @{$self->{tokens}});
-    return $self->{tokens}->[$self->{index}];    
+    return $self->{tokens}->[$self->{index}];
 }
 
 sub collectTokensUntil {
@@ -186,18 +187,18 @@ sub collectTokensUntil {
         # then just advance it one
         $self->nextToken();
         # and return nothing
-        return;        
+        return;
     }
-    
+
     # if it doesnt match our current token then, ...
-    my @collection;    
+    my @collection;
     # store the index we start at
-    my $old_index = $self->{index}; 
-    my $matched;       
+    my $old_index = $self->{index};
+    my $matched;
     # loop through the tokens
     while ($self->hasNextToken()) {
         my $token = $self->nextToken();
-        if ($token ne $token_to_match) {       
+        if ($token ne $token_to_match) {
             push @collection => $token;
         }
         else {
@@ -206,7 +207,7 @@ sub collectTokensUntil {
         }
     }
     unless ($matched) {
-        # reset back to where we started, and ... 
+        # reset back to where we started, and ...
         $self->{index} = $old_index;
         # and return nothing
         return;
@@ -234,9 +235,9 @@ sub skipTokensUntil {
         return 1 if ($self->nextToken() eq $token_to_match);
     }
     # otherwise we didnt match, and should
-    # reset back to where we started, and ... 
+    # reset back to where we started, and ...
     $self->{index} = $old_index;
-    # return failure 
+    # return failure
     return 0;
 }
 
@@ -264,42 +265,42 @@ String::Tokenizer - A simple string tokenizer.
 =head1 SYNOPSIS
 
   use String::Tokenizer;
-  
+
   # create the tokenizer and tokenize input
   my $tokenizer = String::Tokenizer->new("((5+5) * 10)", '+*()');
-  
+
   # create tokenizer
   my $tokenizer = String::Tokenizer->new();
   # ... then tokenize the string
   $tokenizer->tokenize("((5 + 5) - 10)", '()');
-  
+
   # will print '(, (, 5, +, 5, ), -, 10, )'
   print join ", " => $tokenizer->getTokens();
-  
+
   # create tokenizer which retains whitespace
   my $st = String::Tokenizer->new(
-                'this is a test with,    (signifigant) whitespace',
+                'this is a test with,    (significant) whitespace',
                 ',()',
                 String::Tokenizer->RETAIN_WHITESPACE
                 );
-                
+
   # this will print:
-  # 'this', ' ', 'is', ' ', 'a', ' ', 'test', ' ', 'with', '	', '(', 'signifigant', ')', ' ', 'whitespace'
-  print "'" . (join "', '" => $tokenizer->getTokens()) . "'";  
-  
+  # 'this', ' ', 'is', ' ', 'a', ' ', 'test', ' ', 'with', '	', '(', 'significant', ')', ' ', 'whitespace'
+  print "'" . (join "', '" => $tokenizer->getTokens()) . "'";
+
   # get a token iterator
   my $i = $tokenizer->iterator();
   while ($i->hasNextToken()) {
       my $next = $i->nextToken();
       # peek ahead at the next token
       my $look_ahead = $i->lookAheadToken();
-      # ... 
+      # ...
       # skip the next 2 tokens
       $i->skipTokens(2);
-      # ... 
+      # ...
       # then backtrack 1 token
       my $previous = $i->prevToken();
-      # ... 
+      # ...
       # get the current token
       my $current = $i->currentToken();
       # ...
@@ -307,11 +308,11 @@ String::Tokenizer - A simple string tokenizer.
 
 =head1 DESCRIPTION
 
-A simple string tokenizer which takes a string and splits it on whitespace. It also optionally takes a string of characters to use as delimiters, and returns them with the token set as well. This allows for splitting the string in many different ways. 
+A simple string tokenizer which takes a string and splits it on whitespace. It also optionally takes a string of characters to use as delimiters, and returns them with the token set as well. This allows for splitting the string in many different ways.
 
-This is a very basic tokenizer, so more complex needs should be either addressed with a custom written tokenizer or post-processing of the output generated by this module. Basically, this will not fill everyones needs, but it spans a gap between simple C<split / /, $string> and the other options that involve much larger and complex modules.
+This is a very basic tokenizer, so more complex needs should be either addressed with a custom written tokenizer or post-processing of the output generated by this module. Basically, this will not fill everyone's needs, but it spans a gap between simple C<split / /, $string> and the other options that involve much larger and complex modules.
 
-Also note that this is not a lexical analyser. Many people confuse tokenization with lexical analysis. A tokenizer mearly splits its input into specific chunks, a lexical analyzer classifies those chunks. Sometimes these two steps are combined, but not here.
+Also note that this is not a lexical analyser. Many people confuse tokenization with lexical analysis. A tokenizer merely splits its input into specific chunks, a lexical analyzer classifies those chunks. Sometimes these two steps are combined, but not here.
 
 =head1 METHODS
 
@@ -331,15 +332,15 @@ This can be used to set the whitespace handling. It accepts one of the two const
 
 =item B<tokenize ($string, $delimiters, $handle_whitespace)>
 
-Takes a C<$string> to tokenize, and optionally a set of C<$delimiter> characters to facilitate the tokenization and the type of whitespace handling with C<$handle_whitespace>. The C<$string> parameter and the C<$handle_whitespace> parameter are pretty obvious, the C<$delimiter> parameter is not as transparent. C<$delimiter> is a string of characters, these characters are then seperated into individual characters and are used to split the C<$string> with. So given this string:
+Takes a C<$string> to tokenize, and optionally a set of C<$delimiter> characters to facilitate the tokenization and the type of whitespace handling with C<$handle_whitespace>. The C<$string> parameter and the C<$handle_whitespace> parameter are pretty obvious, the C<$delimiter> parameter is not as transparent. C<$delimiter> is a string of characters, these characters are then separated into individual characters and are used to split the C<$string> with. So given this string:
 
   (5 + (100 * (20 - 35)) + 4)
 
-The C<tokenize> method without a C<$delimiter> parameter would return the following comma seperated list of tokens:
+The C<tokenize> method without a C<$delimiter> parameter would return the following comma separated list of tokens:
 
   '(5', '+', '(100', '*', '(20', '-', '35))', '+', '4)'
 
-However, if you were to pass the following set of delimiters C<(, )> to C<tokenize>, you would get the following comma seperated list of tokens:
+However, if you were to pass the following set of delimiters C<(, )> to C<tokenize>, you would get the following comma separated list of tokens:
 
   '(', '5', '+', '(', '100', '*', '(', '20', '-', '35', ')', ')', '+', '4', ')'
 
@@ -347,21 +348,21 @@ We now can differentiate the parens from the numbers, and no globbing occurs. If
 
   (5+(100*(20-35))+4)
 
-as some languages do. Then you would give this delimiter C<+*-()> to arrive at the same result. 
+as some languages do. Then you would give this delimiter C<+*-()> to arrive at the same result.
 
-If you decide that whitespace is signifigant in your string, then you need to specify that like this:
+If you decide that whitespace is significant in your string, then you need to specify that like this:
 
   my $st = String::Tokenizer->new(
-                'this is a test with,    (signifigant) whitespace',
+                'this is a test with,    (significant) whitespace',
                 ',()',
                 String::Tokenizer->RETAIN_WHITESPACE
                 );
 
 A call to C<getTokens> on this instance would result in the following token set.
 
- 'this', ' ', 'is', ' ', 'a', ' ', 'test', ' ', 'with', '	', '(', 'signifigant', ')', ' ', 'whitespace'
+ 'this', ' ', 'is', ' ', 'a', ' ', 'test', ' ', 'with', '	', '(', 'significant', ')', ' ', 'whitespace'
 
-All running whitespace is grouped together into a single token, we make no attempt to split it into its individual parts. 
+All running whitespace is grouped together into a single token, we make no attempt to split it into its individual parts.
 
 =item B<getTokens>
 
@@ -375,7 +376,7 @@ Returns a B<String::Tokenizer::Iterator> instance, see below for more details.
 
 =head1 INNER CLASS
 
-A B<String::Tokenizer::Iterator> instance is returned from the B<String::Tokenizer>'s C<iterator> method and serves as yet another means of iterating through an array of tokens. The simplest way would be to call C<getTokens> and just manipulate the array yourself, or push the array into another object. However, iterating through a set of tokens tends to get messy when done manually. So here I have provided the B<String::Tokenizer::Iterator> to address those common token processing idioms. It is basically a bi-directional iterator which can look ahead, skip and be reset to the begining.
+A B<String::Tokenizer::Iterator> instance is returned from the B<String::Tokenizer>'s C<iterator> method and serves as yet another means of iterating through an array of tokens. The simplest way would be to call C<getTokens> and just manipulate the array yourself, or push the array into another object. However, iterating through a set of tokens tends to get messy when done manually. So here I have provided the B<String::Tokenizer::Iterator> to address those common token processing idioms. It is basically a bi-directional iterator which can look ahead, skip and be reset to the beginning.
 
 B<NOTE:>
 B<String::Tokenizer::Iterator> is an inner class, which means that only B<String::Tokenizer> objects can create an instance of it. That said, if B<String::Tokenizer::Iterator>'s C<new> method is called from outside of the B<String::Tokenizer> package, an exception is thrown.
@@ -388,15 +389,17 @@ This accepts an array reference of tokens and sets up the iterator. This method
 
 =item B<reset>
 
-This will reset the interal counter, bringing it back to the begining of the token list.
+This will reset the internal counter,
+bringing it back to the beginning of the token list.
 
 =item B<hasNextToken>
 
-This will return true (1) if there are more tokens to be iterated over, and false (0) otherwise.
+This will return true (1) if there are more tokens to be iterated over,
+and false (0) otherwise.
 
 =item B<hasPrevToken>
 
-This will return true (1) if the begining of the token list has been reached, and false (0) otherwise.
+This will return true (1) if the beginning of the token list has been reached, and false (0) otherwise.
 
 =item B<nextToken>
 
@@ -454,7 +457,7 @@ Allow for the creation of "token bookmarks". Meaning we could tag a specific tok
 
 =head1 BUGS
 
-None that I am aware of. Of course, if you find a bug, let me know, and I will be sure to fix it. 
+None that I am aware of. Of course, if you find a bug, let me know, and I will be sure to fix it.
 
 =head1 CODE COVERAGE
 
@@ -470,23 +473,31 @@ I use B<Devel::Cover> to test the code coverage of my tests, below is the B<Deve
 
 =head1 SEE ALSO
 
-The interface and workings of this module are based largely on the StringTokenizer class from the Java standard library. 
+The interface and workings of this module are based largely on the StringTokenizer class from the Java standard library.
 
 Below is a short list of other modules that might be considered similar to this one. If this module does not suit your needs, you might look at one of these.
 
 =over 4
 
-=item B<String::Tokeniser>
+=item L<String::Tokeniser>
 
-Along with being a tokenizer, it also provides a means of moving through the resulting tokens, allowing for skipping of tokens and such. But this module looks as if it hasnt been updated from 0.01 and that was uploaded in since 2002. The author (Simon Cozens) includes it in the section of L<Acme::OneHundredNotOut> entitled "The Embarrassing Past". From what I can guess, he does not intend to maintain it anymore.
+Along with being a tokenizer,
+it also provides a means of moving through the resulting tokens,
+allowing for skipping of tokens and such.
+It was last updated in 2011.
 
-=item B<Parse::Tokens>
+=item L<Parse::Tokens>
 
-This one hasn't been touched since 2001, although it did get up to version 0.27. It looks to lean over more towards the parser side than a basic tokenizer. 
+This one hasn't been touched since 2001,
+although it did get up to version 0.27.
+It looks to lean over more towards the parser side than a basic tokenizer.
 
-=item B<Text::Tokenizer>
+=item L<Text::Tokenizer>
 
-This one looks more up to date (updated as recently as March 2004), but is both a lexical analyzer and a tokenizer. It also uses XS, mine is pure perl. This is something maybe to look into if you were to need a more beefy solution that what String::Tokenizer provides.
+This is both a lexical analyzer and a tokenizer.
+It also uses XS, where String::Tokenizer is pure perl.
+This is something maybe to look into if you were to need a more beefy solution
+than String::Tokenizer provides.
 
 =back
 
@@ -500,15 +511,15 @@ This one looks more up to date (updated as recently as March 2004), but is both
 
 =head1 AUTHOR
 
-stevan little, E<lt>stevan@iinteractive.comE<gt>
+stevan little, E<lt>stevan@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004 by Infinity Interactive, Inc.
+Copyright 2004-2016 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
+it under the same terms as Perl itself.
 
 =cut
